[Qa-jenkins-scm] [Git][qa/jenkins.debian.net][master] 4 commits: packages-test: fix yaml so it works with the newest jjb

Mattia Rizzolo gitlab at salsa.debian.org
Wed May 30 13:36:35 BST 2018


Mattia Rizzolo pushed to branch master at Debian QA / jenkins.debian.net


Commits:
97078cf0 by Mattia Rizzolo at 2018-05-30T14:23:08+02:00
packages-test: fix yaml so it works with the newest jjb

Signed-off-by: Mattia Rizzolo <mattia at debian.org>

- - - - -
08a74941 by Mattia Rizzolo at 2018-05-30T14:23:18+02:00
packages-tests: disable pollscm trigger for debhelper and lintian, as it causes double builds with the ones triggered by gitlab

Signed-off-by: Mattia Rizzolo <mattia at debian.org>

- - - - -
81b43815 by Philip Hands at 2018-05-30T14:23:20+02:00
remove remaining lvc debris

- - - - -
4a033807 by Mattia Rizzolo at 2018-05-30T14:23:22+02:00
master_wrapper: retain the RETRIEVE_ARTIFACTS feature, for possible future cases

Signed-off-by: Mattia Rizzolo <mattia at debian.org>

- - - - -


5 changed files:

- − TODO4lvc-removal.txt
- bin/d-i_build.sh
- bin/jenkins_master_wrapper.sh
- job-cfg/d-i.yaml.py
- job-cfg/packages-tests.yaml


Changes:

=====================================
TODO4lvc-removal.txt deleted
=====================================
--- a/TODO4lvc-removal.txt
+++ /dev/null
@@ -1,2 +0,0 @@
-cleanup LVC in bin/d-i_build.sh
-cleanup job-cfg/d-i.yaml.py (search for lvc)


=====================================
bin/d-i_build.sh
=====================================
--- a/bin/jenkins_master_wrapper.sh
+++ b/bin/jenkins_master_wrapper.sh
@@ -30,10 +30,6 @@ case $JOB_NAME in
 	rebootstrap_*|chroot-installation_*)
 		PARAMS="$JOB_NAME $@"
 		;;
-	lvc_*) 		PARAMS="$JOB_NAME $EXECUTOR_NUMBER TRIGGERING_BRANCH=${TRIGGERING_BRANCH:-} $@"
-			RETRIEVE_ARTIFACTS=yes
-			export
-			;;
 	*)		PARAMS="$JOB_NAME"
 			;;
 esac


=====================================
job-cfg/d-i.yaml.py
=====================================
--- a/job-cfg/d-i.yaml.py
+++ b/job-cfg/d-i.yaml.py
@@ -371,7 +371,6 @@ data.append(gen_default(
     ))
 data.append(gen_default(
     name='{name}-pu-triggered',
-    downstream=[{'project': 'lvc_debian-miniiso', 'current-parameters': 'true'}],
     parameters=[ {'string': {'name': 'TRIGGERING_BRANCH', 'description': 'git branch that triggered the build that resulted in this subsequent build.'}}],
     ))
 


=====================================
job-cfg/packages-tests.yaml
=====================================
--- a/job-cfg/packages-tests.yaml
+++ b/job-cfg/packages-tests.yaml
@@ -18,7 +18,7 @@
           url: http://www.profitbricks.co.uk
           text: Sponsored by Profitbricks
           icon: /userContent/images/profitbricks-24x24.png
-    description: '{my_description} running on {my_distro}.<br><br>Job  configuration source is <a href="https://anonscm.debian.org/git/qa/jenkins.debian.net.git/tree/job-cfg/packages-tests.yaml">packages-tests.yaml</a>.'
+    description: '{my_description} running on {my_distro}.<br><br>Job configuration source is <a href="https://salsa.debian.org/qa/jenkins.debian.net.git/blob/master/job-cfg/packages-tests.yaml">packages-tests.yaml</a>.'
     logrotate: &logrotate
       daysToKeep: 90
       numToKeep: 30
@@ -40,7 +40,7 @@
           send-to-individuals: true
       - trigger: &trigger
           project: '{my_trigger}'
-      - gitlab-notifier: &gitlab_notifier
+      - gitlab-notifier: &gitlab_notifier {}
       - naginator: &naginator
           progressive-delay-increment: 5
           progressive-delay-maximum: 15
@@ -89,8 +89,6 @@
           <<: *distro_defaults_sid
           my_origin_triggers:
             - gitlab
-            - pollscm:
-                cron: '* H/2 * * *'
       - buster:
           <<: *distro_defaults_buster
           my_trigger: '{name}_stretch-backports'
@@ -113,8 +111,6 @@
           <<: *distro_defaults_sid
           my_origin_triggers:
             - gitlab
-            - pollscm:
-                cron: '* H/2 * * *'
       - buster: *distro_defaults_buster
       - stretch: *distro_defaults_stretch
     jobs:



View it on GitLab: https://salsa.debian.org/qa/jenkins.debian.net/compare/83ccf898dfec7d35b9edebdfc0cfa32bb3f65db0...4a0338070aefb79d59a8a4c2e86477435eaf4665

--- a/bin/d-i_build.sh
+++ b/bin/d-i_build.sh
@@ -10,7 +10,7 @@ common_init "$@"
 
 RESULT_DIR=$(readlink -f ..)
 ISO_DIR=/srv/d-i/isos
-LVC_HOST=profitbricks-build10-amd64.debian.net
+ISO_TEST_HOST=  # this will be set to wherever we test ISOs we create
 
 [ -v GIT_BRANCH ] || GIT_BRANCH="$(git branch -r --contains $GIT_COMMIT | tail -1 | cut -c3-)"
 
@@ -65,10 +65,12 @@ preserve_artifacts() {
 	fi
 
 	#
 	# Alternatively, if we built an images tarball and were triggered by a pu/ branch
 	#
 	IMAGETAR=${RESULT_DIR}/debian-installer-images_*.tar.gz
-	if [ -f $IMAGETAR -a "$TRIGGERING_BRANCH" ] ; then
+	if [ -f $IMAGETAR -a "$TRIGGERING_BRANCH" -a "$ISO_TEST_HOST" ] ; then
 		[ -d ${ISO_DIR} ] || mkdir ${ISO_DIR}
 
 		echo "untaring the .iso images from $IMAGETAR:"
@@ -84,9 +86,9 @@ preserve_artifacts() {
 
 		if [ "$HOSTNAME" = "jenkins" ] ; then
 			# FIXME this rsync should probably be in a separate job that the one on pb10 could then depend on -- otherwise race conditions seem to lurk
-			echo "and rsync them to the target node ($LVC_HOST):"
-			ssh -o 'Batchmode = yes' $LVC_HOST mkdir -p $ISO_DIR
-			rsync -v -e "ssh -o 'Batchmode = yes'" -r $ISO_DIR/ $LVC_HOST:$ISO_DIR/
+			echo "and rsync them to the target node ($ISO_TEST_HOST):"
+			ssh -o 'Batchmode = yes' $ISO_TEST_HOST mkdir -p $ISO_DIR
+			rsync -v -e "ssh -o 'Batchmode = yes'" -r $ISO_DIR/ $ISO_TEST_HOST:$ISO_DIR/
 		fi
 	fi
 }
@@ -65,10 +65,12 @@ preserve_artifacts() {
 
 	#
-	# Alternatively, if we built an images tarball and were triggered by a pu/ branch
+	# Alternatively, if we built an images tarball
+	#                   and were triggered by a pu/ branch
+	#                   and have somewhere to test the results
 	#
 	IMAGETAR=${RESULT_DIR}/debian-installer-images_*.tar.gz


=====================================
bin/jenkins_master_wrapper.sh
=====================================
-- 
View it on GitLab: https://salsa.debian.org/qa/jenkins.debian.net/compare/83ccf898dfec7d35b9edebdfc0cfa32bb3f65db0...4a0338070aefb79d59a8a4c2e86477435eaf4665
You're receiving this email because of your account on salsa.debian.org.
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://alioth-lists.debian.net/pipermail/qa-jenkins-scm/attachments/20180530/6741a7d8/attachment-0001.html>


More information about the Qa-jenkins-scm mailing list